@@ -6,12 +6,23 @@ import typer
 
 from mypy_gh_action_report.executors import classify_output, handle_output
 
+from . import __version__
+
 IS_ATTY: Final[bool] = sys.stdin.isatty()
+app: typer.Typer = typer.Typer()
 
 
+def version_callback(val: bool) -> None:
+    if val:
+        typer.echo(__version__)
+        raise typer.Exit(code=0)
+
+
+@app.command()
 def run(
     mypy_output: Optional[str] = typer.Argument(None if IS_ATTY else sys.stdin.read(), hidden=True),
     json_only: bool = typer.Option(False, help="Just convert mypy output to json"),
+    _: Optional[bool] = typer.Option(None, "-v", "--version", is_eager=True, callback=version_callback),
 ) -> None:
     classify_output(mypy_output=mypy_output)
     handle_output(mypy_output=typing.cast(str, mypy_output), json_only=json_only)
@@ -19,4 +30,4 @@ def run(
 
 
 def execute() -> None:
-    typer.run(run)
+    app()
